@@ -66,6 +66,7 @@
 enum {
 	PROP_0,
 	PROP_REPLACE,
+	PROP_IDLE_EXIT,
 	LAST_PROP
 };
 
@@ -119,6 +120,7 @@ struct _NotifyDaemon {
 	NotifyDaemonNotifications *skeleton;
 	guint              bus_name_id;
 	gboolean           replace;
+	gboolean           idle_exit;
 
 	NotifyStackLocation stack_location;
 	NotifyScreen* screen;
@@ -186,7 +188,6 @@ static void name_lost_handler_cb (GDBusConnection *connection,
 	gtk_main_quit();
 }
 
-
 static void notify_daemon_constructed (GObject *object)
 {
 	NotifyDaemon *daemon;
@@ -221,6 +222,9 @@ static void notify_daemon_set_property (GObject      *object,
 		case PROP_REPLACE:
 			daemon->replace = g_value_get_boolean (value);
 			break;
+		case PROP_IDLE_EXIT:
+			daemon->idle_exit = g_value_get_boolean (value);
+			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 			break;
@@ -238,6 +242,12 @@ static void notify_daemon_class_init(NotifyDaemonClass* daemon_class)
 		g_param_spec_boolean ("replace", "replace", "replace", FALSE,
 				G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE |
 				G_PARAM_STATIC_STRINGS);
+	properties[PROP_IDLE_EXIT] =
+		g_param_spec_boolean ("idle-exit", "idle-exit",
+				      "Whether to exit when idle", FALSE,
+				      G_PARAM_CONSTRUCT_ONLY |
+				      G_PARAM_WRITABLE |
+				      G_PARAM_STATIC_STRINGS);
 
 	g_object_class_install_properties (object_class, LAST_PROP, properties);
 }
@@ -264,6 +274,9 @@ static void add_exit_timeout(NotifyDaemon* daemon)
 {
 	g_assert (daemon != NULL);
 
+	if (! daemon->idle_exit)
+		return;
+
 	if (daemon->exit_timeout_source > 0)
 		return;
 
@@ -310,54 +323,68 @@ static void on_screen_monitors_changed(GdkScreen* screen, NotifyDaemon* daemon)
 	GdkDisplay     *display;
 	NotifyScreen* nscreen;
 	int n_monitors;
-	int i;
 
 	nscreen = daemon->screen;
 	display = gdk_screen_get_display (screen);
 
 	n_monitors = gdk_display_get_n_monitors(display);
 
-	if (n_monitors > (int) nscreen->n_stacks)
+	if (n_monitors != (int) nscreen->n_stacks)
 	{
-		/* grow */
-		nscreen->stacks = g_renew(NotifyStack *, nscreen->stacks, (gsize) n_monitors);
+		NotifyStack **new_stacks = g_malloc (sizeof *new_stacks * n_monitors);
 
-		/* add more stacks */
-		for (i = (int) nscreen->n_stacks; i < n_monitors; i++)
+		/* create the new list, either moving over from the existing stacks,
+		 * or creating new ones as needed */
+		for (int i = 0; i < n_monitors; i++)
 		{
-			create_stack_for_monitor(daemon, screen, gdk_display_get_monitor (display, i));
+			GdkMonitor *monitor = gdk_display_get_monitor (display, i);
+			gsize j;
+
+			for (j = 0; j < nscreen->n_stacks; j++)
+			{
+				if (nscreen->stacks[j] != NULL &&
+				    notify_stack_get_monitor (nscreen->stacks[j]) == monitor)
+				{
+					new_stacks[i] = nscreen->stacks[j];
+					nscreen->stacks[j] = NULL;
+					break;
+				}
+			}
+			/* not found, create it */
+			if (j >= nscreen->n_stacks)
+				new_stacks[i] = notify_stack_new (daemon, screen, monitor, daemon->stack_location);
 		}
-
-		nscreen->n_stacks = (gsize) n_monitors;
-	}
-	else if (n_monitors < (int) nscreen->n_stacks)
-	{
-		NotifyStack* last_stack;
-
-		last_stack = nscreen->stacks[n_monitors - 1];
-
-		/* transfer items before removing stacks */
-		for (i = n_monitors; i < (int) nscreen->n_stacks; i++)
+		/* transfer items and remove old stacks */
+		for (gsize i = 0; i < nscreen->n_stacks; i++)
 		{
 			NotifyStack* stack = nscreen->stacks[i];
-			GList* windows = g_list_copy(notify_stack_get_windows(stack));
-			GList* l;
 
-			for (l = windows; l != NULL; l = l->next)
+			/* if it has been moved over to the new ones, ignore it */
+			if (stack == NULL)
+				continue;
+
+			if (n_monitors > 0) /* always true, but just to be safe */
 			{
-				/* skip removing the window from the old stack since it will try
-				 * to unrealize the window.
-				 * And the stack is going away anyhow. */
-				notify_stack_add_window(last_stack, l->data, TRUE);
+				int target_idx = n_monitors - 1;
+				GList* windows = g_list_copy (notify_stack_get_windows (stack));
+
+				for (GList *l = windows; l != NULL; l = l->next)
+				{
+					/* skip removing the window from the old stack since it will try
+					 * to unrealize the window.
+					 * And the stack is going away anyhow. */
+					notify_stack_add_window (new_stacks[target_idx], l->data, TRUE);
+				}
+
+				g_list_free(windows);
 			}
 
-			g_list_free(windows);
 			notify_stack_destroy(stack);
 			nscreen->stacks[i] = NULL;
 		}
 
-		/* remove the extra stacks */
-		nscreen->stacks = g_renew(NotifyStack*, nscreen->stacks, (gsize) n_monitors);
+		g_free (nscreen->stacks);
+		nscreen->stacks = new_stacks;
 		nscreen->n_stacks = (gsize) n_monitors;
 	}
 }
@@ -1116,6 +1143,9 @@ static gboolean screensaver_active(GtkWidget* nw)
 	GVariant *variant;
 	GDBusProxy *proxy = NULL;
 
+	if (!(GDK_IS_X11_DISPLAY (gdk_display_get_default ())))
+		return FALSE;
+
 	proxy = g_dbus_proxy_new_for_bus_sync(G_BUS_TYPE_SESSION,
 			G_DBUS_PROXY_FLAGS_NONE,
 			NULL,
@@ -1127,6 +1157,7 @@ static gboolean screensaver_active(GtkWidget* nw)
 	if (proxy == NULL) {
 		g_warning("Failed to get dbus connection: %s", error->message);
 		g_error_free (error);
+		return active;
 	}
 
 	variant = g_dbus_proxy_call_sync (proxy,
@@ -1395,7 +1426,6 @@ static gboolean notify_daemon_notify_handler(NotifyDaemonNotifications *object,
 	 *XXX This needs to handle file URIs and all that.
 	 */
 
-
 #ifdef HAVE_X11
 	if (GDK_IS_X11_DISPLAY (gdk_display_get_default ()) &&
 		g_variant_lookup(hints, "window-xid", "@u", &data))
@@ -1692,7 +1722,10 @@ static gboolean notify_daemon_get_server_information (NotifyDaemonNotifications
 	return TRUE;
 }
 
-NotifyDaemon* notify_daemon_new (gboolean replace)
+NotifyDaemon* notify_daemon_new (gboolean replace, gboolean idle_exit)
 {
-	return g_object_new (NOTIFY_TYPE_DAEMON, "replace", replace, NULL);
+	return g_object_new (NOTIFY_TYPE_DAEMON,
+			     "replace", replace,
+			     "idle-exit", idle_exit,
+			     NULL);
 }
