@@ -26,6 +26,8 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
+#include <libxml/parser.h>
+#include <libxml/xmlmemory.h>
 #include <libxml/xpath.h>
 
 typedef void (*ActionInvokedCb) (GtkWindow* nw, const char* key);
@@ -555,7 +557,7 @@ void set_notification_text(GtkWindow* nw, const char* summary, const char* body)
 		if ((body_label_text == NULL) || (strlen (body_label_text) == 0)) {
 			goto render_fail;
 		}
-		goto renrer_ok;
+		goto render_ok;
 	}
 
 render_fail:
@@ -564,7 +566,7 @@ render_fail:
 	gtk_label_set_markup (GTK_LABEL (windata->body_label), quoted);
 	g_free (quoted);
 
-renrer_ok:
+render_ok:
 	xmlCleanupParser ();
 
 	if (body == NULL || *body == '\0')
